package java.util.concurrent.atomic;

/**
 * A {@code boolean} value that may be updated atomically. See the
 * {@link java.util.concurrent.atomic} package specification for description of
 * the properties of atomic variables. An {@code AtomicBoolean} is used in
 * applications such as atomically updated flags, and cannot be used as a
 * replacement for a {@link java.lang.Boolean}.
 *
 * @since 1.5
 * @author Doug Lea
 */
public class AtomicBoolean {
    boolean value;

    /**
     * Creates a new {@code AtomicBoolean} with initial value {@code false}.
     */
    public AtomicBoolean() {
    }

    /**
     * Atomically sets the value to the given updated value if the current value
     * == the expected value.
     *
     * @param expect
     *            the expected value
     * @param update
     *            the new value
     * @return true if successful. False return indicates that the actual value
     *         was not equal to the expected value.
     */
    public boolean compareAndSet(boolean expect, boolean update) {
        if (value == expect) {
            value = update;
            return true;
        } else {
            return false;
        }
    }

    /**
     * Returns the current value.
     *
     * @return the current value
     */
    public boolean get() {
        return value;
    }

    /**
     * Unconditionally sets to the given value.
     *
     * @param newValue
     *            the new value
     */
    public void set(boolean newValue) {
        value = newValue;
    }
}
